The tool to convert domains to the famous IDNA format.
======================================================

.. image:: https://travis-ci.com/PyFunceble/domain2idna.svg?branch=master
   :target: https://travis-ci.com/PyFunceble/domain2idna
.. image:: https://coveralls.io/repos/github/PyFunceble/domain2idna/badge.svg?branch=master
   :target: https://coveralls.io/github/PyFunceble/domain2idna?branch=master
.. image:: https://api.codacy.com/project/badge/Grade/7fc14987068e409e9ddb70195f2485ab
    :target: https://www.codacy.com/manual/funilrys/domain2idna?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PyFunceble/domain2idna&amp;utm_campaign=Badge_Grade
.. image:: https://img.shields.io/github/license/PyFunceble/domain2idna.svg
   :target: https://github.com/PyFunceble/domain2idna/blob/master/LICENSE
.. image:: https://img.shields.io/github/release/PyFunceble/domain2idna.svg
   :target: https://github.com/PyFunceble/domain2idna/releases/latest
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black


.. toctree::
   :maxdepth: 2
   :caption: Content

   installation
   usage
   code
   issues

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
